Flent: The FLExible Network Tester
==================================

Flent is a Python wrapper to run multiple simultaneous netperf/iperf/ping
instances and aggregate the results. It was previously known as
'netperf-wrapper'. See the web site for the main documentation:
https://flent.org.

Installing Flent
----------------
Installing Flent can be done in several ways, depending on your operating system:

- **Debian and Ubuntu users:** Use the `packages from the Open Build Service
  <https://software.opensuse.org/download.html?project=home:tohojo:flent&package=flent>`_

- **Arch Linux users:** Install 'flent' from the AUR.

- **Other Linux and OSX with Macbrew:** Install from the Python cheese shop:
  ``pip install flent``.


Quick Start
-----------

See https://flent.org/intro.html#quick-start or doc/quickstart.rst.
